import logging
from collections import defaultdict
from datetime import time, timedelta
import datetime

from odoo import api, fields, models
from odoo.tools.translate import _
from odoo.tools.float_utils import float_round
from odoo.addons.resource.models.utils import Intervals

_logger = logging.getLogger(__name__)


class HolidaysType(models.Model):
    _inherit = "hr.leave.type"

    request_unit = fields.Selection(
        [
            ("c_day", "Calendar days"),
            ("day", "Working days"),
            ("hour", "Hours"),
        ],
        default="c_day",
        string="Take Leaves in",
        required=True,
    )
    exclude_holidays = fields.Boolean(
        "Exclude holidays",
        help="Check this box to exclude holidays from calendar days amount.",
    )

    notify_before_start_holidays = fields.Boolean(
        "Notify about start holidays",
        help="Is it necessary to notify the responsible employee before the start of the holidays?",
    )
    responsible_employee_to_notify_id = fields.Many2one(
        "res.users",
        string="Employee to notify",
        help="The employee who needs to be notified",
    )
    days_before_holidays = fields.Integer(
        string="Days before holidays",
        help="How many days before it is necessary to notify the responsible employee about the start of the holidays.",
    )

    def name_get(self):
        if not self._context.get("employee_id"):
            # leave counts is based on employee_id, would be inaccurate if not based on correct employee
            return super(HolidaysType, self).name_get()
        res = []
        for record in self:
            name = record.name
            name = "%(name)s (%(count)s)" % {
                "name": name,
                "count": _("%g remaining ")
                % (
                    float_round(record.virtual_remaining_leaves, precision_digits=2)
                    or 0.0,
                )
                + (_(" hours") if record.request_unit == "hour" else _(" days")),
            }
            res.append((record.id, name))
        return res
