/** @odoo-module **/

import { patch } from '@web/core/utils/patch'

import { TimeOffCalendarYearRenderer } from '@hr_holidays/views/calendar/year/calendar_year_renderer'
import { onWillStart } from '@odoo/owl'
import { serializeDate } from '@web/core/l10n/dates'

patch(
  TimeOffCalendarYearRenderer.prototype,
  {
    /**
     * We add onWillStart to load data from the holidays.calendar model to get holidays, non-working days and rescheduled working days.
     */
    setup() {
      super.setup(...arguments)
      onWillStart(async () => {
        const rangeStart = serializeDate(
          this.props.model.rangeStart,
          'datetime'
        )
        const rangeEnd = serializeDate(this.props.model.rangeEnd, 'datetime')
        const [holidaysList, nonWorkingDaysList, rescheduledWorkDaysList] =
          await this.orm.call('holidays.calendar', 'get_all_holidays', [
            rangeStart,
            rangeEnd
          ])
        this.holidays = holidaysList
        this.nonWorkingDays = nonWorkingDaysList
        this.rescheduledWorkDay = rescheduledWorkDaysList
      })
    },

    /**
     * Redefining onDayRender, adding additional functionality to it to display holidays, non-working days and postponed working days.
     */
    onDayRender(info) {
      const date = luxon.DateTime.fromJSDate(info.date).toISODate()
      if (this.props.model.unusualDays.includes(date)) {
        info.el.classList.add('o_calendar_disabled')
      }

      // New code
      if (this.nonWorkingDays.includes(date)) {
        info.el.classList.add('o_calendar_disabled')
      }
      const element = document.querySelector(
        `.fc-content-skeleton [data-date=${CSS.escape(date)}]`
      )
      if (element && element.classList.contains('fc-today')) {
        element.classList.remove('fc-today')
        element.classList.add('fc-today-day-number-year')
      }
      if (this.holidays.includes(date)) {
        if (element) {
          const day_number = element.querySelector('.fc-day-number')
          day_number.classList.add('hr_holiday_calendar')
          info.el.classList.add("o_calendar_disabled");
        }
      }
      if (this.rescheduledWorkDay.includes(date)) {
        info.el.classList.remove('o_calendar_disabled')
      }
    }
  }
)
